==> paycenter-client-3.3.73.10-merge-sources.jar: cn/com/duiba/paycenter/remoteservice/payment/RemoteChargeService.java <==
package cn.com.duiba.paycenter.remoteservice.payment;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.paycenter.dto.payment.WxRedpacketOrderDto;
import cn.com.duiba.paycenter.dto.payment.charge.ChargeOrderDto;
import cn.com.duiba.paycenter.dto.payment.charge.WxCouponResponse;
import cn.com.duiba.paycenter.dto.payment.charge.abc.AbcWapChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.abc.AbcWapChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.alipay.AlipayNativeChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.alipay.AlipayNativeChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.alipay.AlipayWapChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.alipay.AlipayWapChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.bankofsuzhou.BankOfSuZhouWapChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.bankofsuzhou.BankOfSuZhouWapChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.boc.BocWapChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.boc.BocWapChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.ccb.CcbWapChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.ccb.CcbWapChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.cebXyk.CebXykWapChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.cebXyk.CebXykWapChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.citic.CiticWapChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.citic.CiticWapChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.cmb.CmbOneNetPayRequest;
import cn.com.duiba.paycenter.dto.payment.charge.cmb.CmbOneNetPayResponse;
import cn.com.duiba.paycenter.dto.payment.charge.duibaLive.bf.DuibaLiveBFChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.duibaLive.bf.DuibaLiveBFChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.duibaLive.installment.DuibaLiveInstallmentChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.duibaLive.installment.DuibaLiveInstallmentChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.duibaLive.mp.DuibaLiveMpChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.duibaLive.mp.DuibaLiveMpChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.hello.HelloPayChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.hello.HelloPayChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.icbc.IcbcH5ChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.icbc.IcbcH5ChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.mock.MockWapChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.mock.MockWapChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.ningbobank.charge.NbcbChargeRequestDto;
import cn.com.duiba.paycenter.dto.payment.charge.ningbobank.charge.NbcbChargeResponseDto;
import cn.com.duiba.paycenter.dto.payment.charge.qingdaobank.QingdaoBankPayChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.qingdaobank.QingdaoBankPayChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.shouxin.ShouxinPayChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.shouxin.ShouxinPayChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.unionpay.UnionPayWapChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.unionpay.UnionPayWapChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.wjrcb.WjrcbPayWxPubChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.wjrcb.WjrcbPayWxPubChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.wxpay.*;
import cn.com.duiba.paycenter.result.FundTransferResult;

import java.util.Date;
import java.util.List;

/**
 * @author zhangruofan
 * @date 2018/11/14
 */
@AdvancedFeignClient
public interface RemoteChargeService {
    /**
     * 微信H5支付收单接口
     *
     * @param chargeRequest 支付请求
     * @return WxPayWapChargeResponse
     * @throws BizException bizException
     */
    WxPayWapChargeResponse createWxPayWapCharge(WxPayWapChargeRequest chargeRequest) throws BizException;

    /**
     * 微信公众号支付收单接口
     *
     * @param chargeRequest 支付请求
     * @return WxPayMpChargeResponse
     * @throws BizException bizException
     */
    WxPayMpChargeResponse createWxPayMpCharge(WxPayMpChargeRequest chargeRequest) throws BizException;

    /**
     * 微信小程序收单接口
     * @param chargeRequest 支付请求
     * @return WxPayLiteChargeResponse
     * @throws BizException bizException
     */
    WxPayLiteChargeResponse createWxPayLiteCharge(WxPayLiteChargeRequest chargeRequest) throws BizException;

    /**
     * 微信扫一扫收单接口
     * 返回扫一扫二维码
     * @param chargeRequest wxpay native charge
     * @return wxpay native response
     * @throws BizException bizException
     */
    WxPayNativeChargeResponse createWxPayNativeCharge(WxPayNativeChargeRequest chargeRequest) throws BizException;

    /**
     * 发起支付宝手机网站支付请求
     *
     * @param chargeRequest 支付请求参数
     * @return response
     * @throws BizException bizException
     */
    AlipayWapChargeResponse createAlipayWapCharge(AlipayWapChargeRequest chargeRequest) throws BizException;

    /**
     * 发起支付宝扫一扫支付请求
     * @param chargeRequest alipay native request
     * @return alipay response
     * @throws BizException bizException
     */
    AlipayNativeChargeResponse createAlipayNativeCharge(AlipayNativeChargeRequest chargeRequest) throws BizException;

    /**
     * 苏州银行支付
     * @param chargeRequest suzhou pay request
     * @return suzhou pay response
     * @throws BizException bizException
     */
    BankOfSuZhouWapChargeResponse createSuZhouCharge(BankOfSuZhouWapChargeRequest chargeRequest) throws BizException;


    /**
     * 建设银行支付
     * @param chargeRequest ccb pay request
     * @return ccb pay response
     * @throws BizException bizException
     */
    CcbWapChargeResponse createCcbCharge(CcbWapChargeRequest chargeRequest) throws BizException;
    /**
     * 苏州农商行微信公众号支付
     * @param chargeRequest wjrcb pay request
     * @return wjrcb pay response
     * @throws BizException bizException
     */
    WjrcbPayWxPubChargeResponse createWjrcbWxPubCharge(WjrcbPayWxPubChargeRequest chargeRequest) throws BizException;

    /**
     * 招商银行一网通支付
     * @param chargeRequest
     * @return
     * @throws BizException
     */
    CmbOneNetPayResponse createCmbOneNetCharge(CmbOneNetPayRequest chargeRequest) throws BizException;

    /**
     * 查询支付订单详情
     *
     * @param orderNo 支付订单号
     * @return chargeOrderDto
     * @throws BizException bizException
     */
    ChargeOrderDto findByOrderNo(String orderNo) throws BizException;

    /**
     * 根据业务订单号查询支付信息
     *
     * @param bizOrderNo 业务主订单号
     * @return chargeOrderDto
     * @throws BizException bizException
     */
    List<ChargeOrderDto> findByBizOrderNo(String bizOrderNo) throws BizException;

    /**
     * 查询支付订单详情
     *
     * @param orderNos 支付订单号
     * @return List<ChargeOrderDto>
     * @throws BizException bizException
     */
    List<ChargeOrderDto> batchFindByOrderNo(List<String> orderNos) throws BizException;

    /**
     * 查询支付订单详情
     *
     * @param transactionNos 交易流水号
     * @return List<ChargeOrderDto>
     * @throws BizException bizException
     */
    List<ChargeOrderDto> batchFindByTransactionNo(List<String> transactionNos) throws BizException;

    /**
     * 构造oauth2授权的url连接
     *
     * @param appId       兑吧appId
     * @param redirectURI 跳转的url
     * @return url
     * @throws BizException bizException
     *
     * the latest version：oauth2buildAuthorizationUrlBySubject
     */
    @Deprecated
    String oauth2buildAuthorizationUrl(Long appId, String redirectURI) throws BizException;

    /**
     * 获取支付订单详情
     * @param bizNo 业务方流水号
     * @param bizType 业务方类型
     * @return ChargeOrderDto
     */
    ChargeOrderDto findByBizNoAndBizType(String bizNo, Integer bizType);

    /**
     * 同一个biztype 多个bizOrderNo批量查询
     * @param bizNos
     * @param bizType
     * @return
     */
    public List<ChargeOrderDto> selectByBizNosAndBizType(List<String> bizNos, Integer bizType);

    /**
     * 同一个biztype 多个bizOrderNo批量查询
     * @param bizNos
     * @param bizType
     * @return
     */
     List<ChargeOrderDto> listByBizNosAndBizType(List<String> bizNos, Integer bizType);

    /**
     * 农行支付
     * @param chargeRequest abc pay request
     * @return abc pay response
     * @throws BizException bizException
     */
    AbcWapChargeResponse createAbcCharge(AbcWapChargeRequest chargeRequest) throws BizException;

    /**
     * 中国银行支付
     * @param chargeRequest boc pay request
     * @return boc pay response
     * @throws BizException bizException
     */
    BocWapChargeResponse createBocCharge(BocWapChargeRequest chargeRequest) throws BizException;

    /**
     * 银联云闪付
     *
     * @param chargeRequest union pay request
     * @return union pay response
     * @throws BizException bizException
     */
    UnionPayWapChargeResponse createUnionPayCharge(UnionPayWapChargeRequest chargeRequest) throws BizException;

    /**
     * 中信银行支付
     * @param chargeRequest citic pay request
     * @return citic pay response
     * @throws BizException bizException
     */
    CiticWapChargeResponse createCiticCharge(CiticWapChargeRequest chargeRequest) throws BizException;


    /**
     * 构造oauth2授权的url连接  --  区分业务主体
     *
     * @return url
     * @throws BizException
     */
    String oauth2buildAuthorizationUrlBySubject(BuildAuthorizationUrlRequest request) throws BizException;

    /**
     * 哈啰零钱支付请求
     *
     * @param chargeRequest 支付请求参数
     * @return response
     * @throws BizException bizException
     */
    HelloPayChargeResponse createHelloPayCharge(HelloPayChargeRequest chargeRequest) throws BizException;

    /**
     * 首信支付请求
     *
     * @param chargeRequest 支付请求参数
     * @return response
     * @throws BizException bizException
     */
    ShouxinPayChargeResponse createShouxinPayCharge(ShouxinPayChargeRequest chargeRequest) throws BizException;
    /**
     * 青岛银行支付请求
     *
     * @param chargeRequest 支付请求参数
     * @return response
     * @throws BizException bizException
     */
    QingdaoBankPayChargeResponse createQingdaoBankPayCharge(QingdaoBankPayChargeRequest chargeRequest) throws BizException;

    /**
     * 微信小程序收单接口 - 客集集(临时)
     * @param chargeRequest 支付请求
     * @return WxPayLiteChargeResponse
     * @throws BizException bizException
     */
    WxPayLiteChargeResponse createWxPayLiteChargeForKejiji(WxPayLiteChargeRequest chargeRequest) throws BizException;

    /**
     * 微信支付关单
     * @param request
     * @throws BizException
     */
    void closeOrder(WxCloseOrderRequest request) throws BizException;

    /**
     * 发送微信红包
     *
     * @param request 请求
     * @return {@link WxRedpacketOrderDto}
     * @throws BizException 业务异常
     */
    WxRedpacketOrderDto sendWxRedPacket(WxPayRedPacketSendRequest request) throws BizException;


    /**
     * 异步发送微信红包（只负责交给线程池处理）
     *
     * @param request 请求
     * @return {@link WxRedpacketOrderDto}
     * @throws BizException 业务异常
     */
    FundTransferResult asynSendWxRedPacket(WxPayRedPacketSendRequest request);

    /**
     * 微信红包订单信息查询
     *
     * @param request 请求
     * @return {@link WxRedpacketOrderDto}
     * @throws BizException 业务异常
     */
    WxRedpacketOrderDto queryWxRedPacketInfo(WxPayRedPacketQueryRequest request) throws BizException;

    /**
     * mock订单支付
     * @param chargeRequest
     * @return
     * @throws BizException
     */
    MockWapChargeResponse createMockCharge(MockWapChargeRequest chargeRequest) throws BizException;

    /**
     * 工行e支付
     * @param chargeRequest
     * @return
     * @throws BizException
     */
    IcbcH5ChargeResponse createIcbcCharge(IcbcH5ChargeRequest chargeRequest) throws BizException;

    /**
     * 发放微信代金券（目前仅支持兑吧业务主体）
     *
     * @param request 请求
     * @return {@link WxRedpacketOrderDto}
     * @throws BizException 业务异常
     */
    WxCouponResponse sendWxCoupon(WxCouponSendRequest request) throws BizException;

    /**
     * 中国光大银行信用卡中信支付
     *
     * @param chargeRequest
     * @return
     * @throws BizException
     */
    CebXykWapChargeResponse createCebXykCharge(CebXykWapChargeRequest chargeRequest) throws BizException;

    /**
     * 兑吧直播小程序支付
     *
     * @param chargeRequest
     * @return
     * @throws BizException
     */
    DuibaLiveMpChargeResponse createDuibaLiveMpCharge(DuibaLiveMpChargeRequest chargeRequest) throws BizException;

    /**
     * 兑吧直播分期支付
     *
     * @param chargeRequest
     * @return
     * @throws BizException
     */
    DuibaLiveInstallmentChargeResponse createDuibaLiveInstallmentCharge(DuibaLiveInstallmentChargeRequest chargeRequest) throws BizException;

    /**
     * 通过orderNo更新订单
     * @param chargeOrderDto 需要更新的字段
     * @return 影响行数
     */
    Boolean update(ChargeOrderDto  chargeOrderDto);
    /**
     *
     * @param appIds 不能为空
     * @param chargeStatus 退款订单状态  不能为null
     * @param startGmtCreate 开始创建时间 不能为null
     * @param endGmtCreate 结束创建时间 不能为null
     * @param limit 最大个数 上限为10000
     * @return
     */
    List<ChargeOrderDto> listByAppIdsAndChargeStatus(List<Long> appIds, Integer chargeStatus, Date startGmtCreate, Date endGmtCreate,Integer limit);



    /**
     * 兑吧直播宝付支付
     *
     * @param chargeRequest
     * @return
     * @throws BizException
     */
    DuibaLiveBFChargeResponse createDuibaLiveBFCharge(DuibaLiveBFChargeRequest chargeRequest) throws BizException;


    /**
     * 宁波银行预下单
     * @param chargeRequestDto
     * @return
     * @throws BizException
     */
    NbcbChargeResponseDto createNingboBankPayCharge(NbcbChargeRequestDto chargeRequestDto) throws BizException;
}

==> paycenter-client-3.3.74.17-merge-sources.jar: cn/com/duiba/paycenter/remoteservice/payment/RemoteChargeService.java <==
package cn.com.duiba.paycenter.remoteservice.payment;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.boot.netflix.feign.hystrix.FeignHystrixProperty;
import cn.com.duiba.boot.netflix.feign.hystrix.conf.HystrixPropertiesManager;
import cn.com.duiba.paycenter.dto.payment.WxRedpacketOrderDto;
import cn.com.duiba.paycenter.dto.payment.charge.ChargeOrderDto;
import cn.com.duiba.paycenter.dto.payment.charge.WxCouponResponse;
import cn.com.duiba.paycenter.dto.payment.charge.abc.AbcWapChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.abc.AbcWapChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.alipay.AlipayNativeChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.alipay.AlipayNativeChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.alipay.AlipayWapChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.alipay.AlipayWapChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.bankofsuzhou.BankOfSuZhouWapChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.bankofsuzhou.BankOfSuZhouWapChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.boc.BocWapChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.boc.BocWapChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.ccb.CcbWapChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.ccb.CcbWapChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.cebXyk.CebXykWapChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.cebXyk.CebXykWapChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.citic.CiticWapChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.citic.CiticWapChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.cmb.CmbOneNetPayRequest;
import cn.com.duiba.paycenter.dto.payment.charge.cmb.CmbOneNetPayResponse;
import cn.com.duiba.paycenter.dto.payment.charge.duibaLive.bf.DuibaLiveBFChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.duibaLive.bf.DuibaLiveBFChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.duibaLive.installment.DuibaLiveInstallmentChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.duibaLive.installment.DuibaLiveInstallmentChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.duibaLive.mp.DuibaLiveMpChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.duibaLive.mp.DuibaLiveMpChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.hello.HelloPayChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.hello.HelloPayChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.icbc.IcbcH5ChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.icbc.IcbcH5ChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.mock.MockWapChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.mock.MockWapChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.ningbobank.charge.NbcbChargeRequestDto;
import cn.com.duiba.paycenter.dto.payment.charge.ningbobank.charge.NbcbChargeResponseDto;
import cn.com.duiba.paycenter.dto.payment.charge.qingdaobank.QingdaoBankPayChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.qingdaobank.QingdaoBankPayChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.shouxin.ShouxinPayChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.shouxin.ShouxinPayChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.unionpay.UnionPayWapChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.unionpay.UnionPayWapChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.wjrcb.WjrcbPayWxPubChargeRequest;
import cn.com.duiba.paycenter.dto.payment.charge.wjrcb.WjrcbPayWxPubChargeResponse;
import cn.com.duiba.paycenter.dto.payment.charge.wxpay.*;
import cn.com.duiba.paycenter.result.FundTransferResult;

import java.util.Date;
import java.util.List;

/**
 * @author zhangruofan
 * @date 2018/11/14
 */
@AdvancedFeignClient
public interface RemoteChargeService {
    /**
     * 微信H5支付收单接口
     *
     * @param chargeRequest 支付请求
     * @return WxPayWapChargeResponse
     * @throws BizException bizException
     */
    WxPayWapChargeResponse createWxPayWapCharge(WxPayWapChargeRequest chargeRequest) throws BizException;

    /**
     * 微信公众号支付收单接口
     *
     * @param chargeRequest 支付请求
     * @return WxPayMpChargeResponse
     * @throws BizException bizException
     */
    WxPayMpChargeResponse createWxPayMpCharge(WxPayMpChargeRequest chargeRequest) throws BizException;

    /**
     * 微信小程序收单接口
     * @param chargeRequest 支付请求
     * @return WxPayLiteChargeResponse
     * @throws BizException bizException
     */
    WxPayLiteChargeResponse createWxPayLiteCharge(WxPayLiteChargeRequest chargeRequest) throws BizException;

    /**
     * 微信扫一扫收单接口
     * 返回扫一扫二维码
     * @param chargeRequest wxpay native charge
     * @return wxpay native response
     * @throws BizException bizException
     */
    WxPayNativeChargeResponse createWxPayNativeCharge(WxPayNativeChargeRequest chargeRequest) throws BizException;

    /**
     * 发起支付宝手机网站支付请求
     *
     * @param chargeRequest 支付请求参数
     * @return response
     * @throws BizException bizException
     */
    AlipayWapChargeResponse createAlipayWapCharge(AlipayWapChargeRequest chargeRequest) throws BizException;

    /**
     * 发起支付宝扫一扫支付请求
     * @param chargeRequest alipay native request
     * @return alipay response
     * @throws BizException bizException
     */
    AlipayNativeChargeResponse createAlipayNativeCharge(AlipayNativeChargeRequest chargeRequest) throws BizException;

    /**
     * 苏州银行支付
     * @param chargeRequest suzhou pay request
     * @return suzhou pay response
     * @throws BizException bizException
     */
    BankOfSuZhouWapChargeResponse createSuZhouCharge(BankOfSuZhouWapChargeRequest chargeRequest) throws BizException;


    /**
     * 建设银行支付
     * @param chargeRequest ccb pay request
     * @return ccb pay response
     * @throws BizException bizException
     */
    CcbWapChargeResponse createCcbCharge(CcbWapChargeRequest chargeRequest) throws BizException;
    /**
     * 苏州农商行微信公众号支付
     * @param chargeRequest wjrcb pay request
     * @return wjrcb pay response
     * @throws BizException bizException
     */
    WjrcbPayWxPubChargeResponse createWjrcbWxPubCharge(WjrcbPayWxPubChargeRequest chargeRequest) throws BizException;

    /**
     * 招商银行一网通支付
     * @param chargeRequest
     * @return
     * @throws BizException
     */
    CmbOneNetPayResponse createCmbOneNetCharge(CmbOneNetPayRequest chargeRequest) throws BizException;

    /**
     * 查询支付订单详情
     *
     * @param orderNo 支付订单号
     * @return chargeOrderDto
     * @throws BizException bizException
     */
    ChargeOrderDto findByOrderNo(String orderNo) throws BizException;

    /**
     * 根据业务订单号查询支付信息
     *
     * @param bizOrderNo 业务主订单号
     * @return chargeOrderDto
     * @throws BizException bizException
     */
    List<ChargeOrderDto> findByBizOrderNo(String bizOrderNo) throws BizException;

    /**
     * 查询支付订单详情
     *
     * @param orderNos 支付订单号
     * @return List<ChargeOrderDto>
     * @throws BizException bizException
     */
    List<ChargeOrderDto> batchFindByOrderNo(List<String> orderNos) throws BizException;

    /**
     * 查询支付订单详情
     *
     * @param transactionNos 交易流水号
     * @return List<ChargeOrderDto>
     * @throws BizException bizException
     */
    List<ChargeOrderDto> batchFindByTransactionNo(List<String> transactionNos) throws BizException;

    /**
     * 构造oauth2授权的url连接
     *
     * @param appId       兑吧appId
     * @param redirectURI 跳转的url
     * @return url
     * @throws BizException bizException
     *
     * the latest version：oauth2buildAuthorizationUrlBySubject
     */
    @Deprecated
    String oauth2buildAuthorizationUrl(Long appId, String redirectURI) throws BizException;

    /**
     * 获取支付订单详情
     * @param bizNo 业务方流水号
     * @param bizType 业务方类型
     * @return ChargeOrderDto
     */
    ChargeOrderDto findByBizNoAndBizType(String bizNo, Integer bizType);

    /**
     * 同一个biztype 多个bizOrderNo批量查询
     * @param bizNos
     * @param bizType
     * @return
     */
    public List<ChargeOrderDto> selectByBizNosAndBizType(List<String> bizNos, Integer bizType);

    /**
     * 同一个biztype 多个bizOrderNo批量查询
     * @param bizNos
     * @param bizType
     * @return
     */
     List<ChargeOrderDto> listByBizNosAndBizType(List<String> bizNos, Integer bizType);

    /**
     * 农行支付
     * @param chargeRequest abc pay request
     * @return abc pay response
     * @throws BizException bizException
     */
    AbcWapChargeResponse createAbcCharge(AbcWapChargeRequest chargeRequest) throws BizException;

    /**
     * 中国银行支付
     * @param chargeRequest boc pay request
     * @return boc pay response
     * @throws BizException bizException
     */
    BocWapChargeResponse createBocCharge(BocWapChargeRequest chargeRequest) throws BizException;

    /**
     * 银联云闪付
     *
     * @param chargeRequest union pay request
     * @return union pay response
     * @throws BizException bizException
     */
    UnionPayWapChargeResponse createUnionPayCharge(UnionPayWapChargeRequest chargeRequest) throws BizException;

    /**
     * 中信银行支付
     * @param chargeRequest citic pay request
     * @return citic pay response
     * @throws BizException bizException
     */
    CiticWapChargeResponse createCiticCharge(CiticWapChargeRequest chargeRequest) throws BizException;


    /**
     * 构造oauth2授权的url连接  --  区分业务主体
     *
     * @return url
     * @throws BizException
     */
    String oauth2buildAuthorizationUrlBySubject(BuildAuthorizationUrlRequest request) throws BizException;

    /**
     * 哈啰零钱支付请求
     *
     * @param chargeRequest 支付请求参数
     * @return response
     * @throws BizException bizException
     */
    HelloPayChargeResponse createHelloPayCharge(HelloPayChargeRequest chargeRequest) throws BizException;

    /**
     * 首信支付请求
     *
     * @param chargeRequest 支付请求参数
     * @return response
     * @throws BizException bizException
     */
    ShouxinPayChargeResponse createShouxinPayCharge(ShouxinPayChargeRequest chargeRequest) throws BizException;
    /**
     * 青岛银行支付请求
     *
     * @param chargeRequest 支付请求参数
     * @return response
     * @throws BizException bizException
     */
    @FeignHystrixProperty(name= HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value="10000")
    QingdaoBankPayChargeResponse createQingdaoBankPayCharge(QingdaoBankPayChargeRequest chargeRequest) throws BizException;

    /**
     * 微信小程序收单接口 - 客集集(临时)
     * @param chargeRequest 支付请求
     * @return WxPayLiteChargeResponse
     * @throws BizException bizException
     */
    WxPayLiteChargeResponse createWxPayLiteChargeForKejiji(WxPayLiteChargeRequest chargeRequest) throws BizException;

    /**
     * 微信支付关单
     * @param request
     * @throws BizException
     */
    void closeOrder(WxCloseOrderRequest request) throws BizException;

    /**
     * 发送微信红包
     *
     * @param request 请求
     * @return {@link WxRedpacketOrderDto}
     * @throws BizException 业务异常
     */
    WxRedpacketOrderDto sendWxRedPacket(WxPayRedPacketSendRequest request) throws BizException;


    /**
     * 异步发送微信红包（只负责交给线程池处理）
     *
     * @param request 请求
     * @return {@link WxRedpacketOrderDto}
     * @throws BizException 业务异常
     */
    FundTransferResult asynSendWxRedPacket(WxPayRedPacketSendRequest request);

    /**
     * 微信红包订单信息查询
     *
     * @param request 请求
     * @return {@link WxRedpacketOrderDto}
     * @throws BizException 业务异常
     */
    WxRedpacketOrderDto queryWxRedPacketInfo(WxPayRedPacketQueryRequest request) throws BizException;

    /**
     * mock订单支付
     * @param chargeRequest
     * @return
     * @throws BizException
     */
    MockWapChargeResponse createMockCharge(MockWapChargeRequest chargeRequest) throws BizException;

    /**
     * 工行e支付
     * @param chargeRequest
     * @return
     * @throws BizException
     */
    IcbcH5ChargeResponse createIcbcCharge(IcbcH5ChargeRequest chargeRequest) throws BizException;

    /**
     * 发放微信代金券（目前仅支持兑吧业务主体）
     *
     * @param request 请求
     * @return {@link WxRedpacketOrderDto}
     * @throws BizException 业务异常
     */
    WxCouponResponse sendWxCoupon(WxCouponSendRequest request) throws BizException;

    /**
     * 中国光大银行信用卡中信支付
     *
     * @param chargeRequest
     * @return
     * @throws BizException
     */
    CebXykWapChargeResponse createCebXykCharge(CebXykWapChargeRequest chargeRequest) throws BizException;

    /**
     * 兑吧直播小程序支付
     *
     * @param chargeRequest
     * @return
     * @throws BizException
     */
    DuibaLiveMpChargeResponse createDuibaLiveMpCharge(DuibaLiveMpChargeRequest chargeRequest) throws BizException;

    /**
     * 兑吧直播分期支付
     *
     * @param chargeRequest
     * @return
     * @throws BizException
     */
    DuibaLiveInstallmentChargeResponse createDuibaLiveInstallmentCharge(DuibaLiveInstallmentChargeRequest chargeRequest) throws BizException;

    /**
     * 通过orderNo更新订单
     * @param chargeOrderDto 需要更新的字段
     * @return 影响行数
     */
    Boolean update(ChargeOrderDto  chargeOrderDto);
    /**
     *
     * @param appIds 不能为空
     * @param chargeStatus 退款订单状态  不能为null
     * @param startGmtCreate 开始创建时间 不能为null
     * @param endGmtCreate 结束创建时间 不能为null
     * @param limit 最大个数 上限为10000
     * @return
     */
    List<ChargeOrderDto> listByAppIdsAndChargeStatus(List<Long> appIds, Integer chargeStatus, Date startGmtCreate, Date endGmtCreate,Integer limit);



    /**
     * 兑吧直播宝付支付
     *
     * @param chargeRequest
     * @return
     * @throws BizException
     */
    DuibaLiveBFChargeResponse createDuibaLiveBFCharge(DuibaLiveBFChargeRequest chargeRequest) throws BizException;


    /**
     * 宁波银行预下单
     * @param chargeRequestDto
     * @return
     * @throws BizException
     */
    NbcbChargeResponseDto createNingboBankPayCharge(NbcbChargeRequestDto chargeRequestDto) throws BizException;
}
